.. highlight:: shell

============
Installation
============

Stable release
--------------

To install MetaNetMap, run this command in your terminal:

.. code-block:: bash

   pip install metanetmap

Development version
-------------------

To install the latest development version from source:

.. code-block:: bash

   git clone git@github.com:coraliemuller/metanetmap.git
   cd metanetmap
   pip install -r requirements.txt
   pip install -r requirements_dev.txt
   pip install .

Dependencies
============

MetaNetMap dependencies:

- pandas
- numpy
- cobra
- setuptools
- aiohttp
- tqdm


Now that installation is complete, you can proceed to the :doc:`quickstart`.
